==> nexus-3.15.2-01-unix.tar.gz: static/rapture/NX/coreui/model/ComponentAssetTree.js <==
/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global Ext, NX*/

/**
 * Component/Asset tree model.
 *
 * @since 3.6
 */
Ext.define('NX.coreui.model.ComponentAssetTree', {
  extend: 'Ext.data.Model',
  mixins: {
    componentUtils: 'NX.coreui.mixin.ComponentUtils'
  },
  fields: [
    {name: 'id', type: 'string', sortType: 'asUCText'},
    {name: 'type', type: 'string', sortType: 'asUCText'},
    {name: 'text', type: 'string', convert: Ext.util.Format.htmlEncode},
    {name: 'iconCls', type: 'string', convert: function(value, record){
        var icon = record.mixins.componentUtils.getIconForAsset(record);
        if (icon) {
          return icon.get('cls');
        }
    }},
    {name: 'leaf', type: 'boolean'},
    {name: 'componentId', type: 'string'},
    {name: 'assetId', type: 'string'}
  ]
});

==> nexus-3.40.1-01-unix.tar.gz: static/rapture/NX/coreui/model/ComponentAssetTree.js <==
/*
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2008-present Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Open Source Version is distributed with Sencha Ext JS pursuant to a FLOSS Exception agreed upon
 * between Sonatype, Inc. and Sencha Inc. Sencha Ext JS is licensed under GPL v3 and cannot be redistributed as part of a
 * closed source work.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global Ext, NX*/

/**
 * Component/Asset tree model.
 *
 * @since 3.6
 */
Ext.define('NX.coreui.model.ComponentAssetTree', {
  extend: 'Ext.data.Model',
  mixins: {
    componentUtils: 'NX.coreui.mixin.ComponentUtils'
  },
  fields: [
    {name: 'id', type: 'string', sortType: 'asUCText'},
    {name: 'type', type: 'string', sortType: 'asUCText'},
    {name: 'text', type: 'string', convert: Ext.util.Format.htmlEncode},
    {name: 'iconCls', type: 'string', convert: function(value, record){
        var icon = record.mixins.componentUtils.getIconForAsset(record);
        if (icon) {
          return icon.get('cls');
        }
    }},
    {name: 'leaf', type: 'boolean'},
    {name: 'componentId', type: 'string'},
    {name: 'assetId', type: 'string'},
    {name: 'vulnerable', type: 'boolean'},
    {name: 'packageUrl', type: 'string'}
  ]
});
